<?php

namespace backend\controllers;

use Yii;
use common\models\SeoDynamic;
use common\models\SeoDynamicSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;

/**
 * SeoDynamicController implements the CRUD actions for SeoDynamic model.
 */
class SeoDynamicController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all SeoDynamic models.
     * @return mixed
     */
    public function actionIndex($seo_category_id)
    {
        $searchModel = new SeoDynamicSearch();
        $dataProvider = $searchModel->search($seo_category_id,Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'seo_category_id' => $seo_category_id
        ]);
    }

    /**
     * Displays a single SeoDynamic model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($seo_category_id, $id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
            'seo_category_id' => $seo_category_id
        ]);
    }

    /**
     * Creates a new SeoDynamic model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate($seo_category_id)
    {
        $model = new SeoDynamic();

        if ($model->load(Yii::$app->request->post())) {
            $model->seo_category_id = $seo_category_id;
            $model->save();
            return $this->redirect(['index', 'seo_category_id' => $model->seo_category_id]);
        } else {
            return $this->render('create', [
                'model' => $model,
                'seo_category_id' => $seo_category_id
            ]);
        }
    }

    /**
     * Updates an existing SeoDynamic model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($seo_category_id,$id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
            return $this->redirect(['index', 'seo_category_id' => $model->seo_category_id]);
        } else {
            return $this->render('update', [
                'model' => $model,
                'seo_category_id' => $seo_category_id
            ]);
        }
    }

    /**
     * Deletes an existing SeoDynamic model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($seo_category_id,$id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index','seo_category_id'=> $seo_category_id]);
    }

    /**
     * Finds the SeoDynamic model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return SeoDynamic the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = SeoDynamic::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
