<?php

namespace common\models;

use Yii;
use yii\behaviors\TimestampBehavior;
/**
 * This is the model class for table "event".
 *
 * @property integer $event_id
 * @property string $name
 * @property string $alias
 * @property string $body
 * @property string $image
 * @property string $meta_title
 * @property string $description
 * @property string $h1
 * @property string $seo_text
 * @property integer $created_at
 * @property integer $updated_at
 * @property integer $end_at
 */
class Event extends \yii\db\ActiveRecord
{

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'event';
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            TimestampBehavior::className(),
            'slug' => [
                'class' => 'common\behaviors\Slug',
                'in_attribute' => 'name',
                'out_attribute' => 'alias',
                'translit' => true
            ],
            [
                'class'              => 'common\behaviors\ShowImage',
            ],
        ];
    }


    public function beforeSave($insert)
    {
        if (parent::beforeSave($insert)) {
            $this->end_at = strtotime($this->end_at);
            return true;
        } else {
            return false;
        }
    }

    public function afterFind(){
        $this->end_at = date("Y-m-d", $this->end_at);
    }


    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['body', 'seo_text'], 'string'],
            [['created_at', 'updated_at' ], 'integer'],
            [['name', 'alias', 'image', 'meta_title', 'description', 'h1','end_at'], 'string', 'max' => 255],
            [['name','body'], 'required'],
            [['image'], 'file'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'event_id' => Yii::t('app', 'event_id'),
            'name' => Yii::t('app', 'name'),
            'alias' => Yii::t('app', 'alias'),
            'body' => Yii::t('app', 'body'),
            'image' => Yii::t('app', 'image'),
            'meta_title' => Yii::t('app', 'meta_title'),
            'description' => Yii::t('app', 'description'),
            'h1' => Yii::t('app', 'h1'),
            'seo_text' => Yii::t('app', 'seo_text'),
            'created_at' => Yii::t('app', 'created_at'),
            'updated_at' => Yii::t('app', 'updated_at'),
            'end_at' => Yii::t('app', 'end_at'),
        ];
    }

    public function getImageUrl() {
        return empty($this->image) ? null : '/storage/event/'. $this->image;
    }
}
