<?php

namespace common\modules\product\models;

use common\components\artboxtree\ArtboxTreeHelper;
use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use common\modules\product\models\Category;
use yii\web\NotFoundHttpException;

/**
 * CategorySearch represents the model behind the search form about `common\modules\product\models\Category`.
 */
class CategorySearch extends Category
{
    public function behaviors()
    {
        $behaviors = parent::behaviors();
        if (isset($behaviors['slug'])) {
            unset($behaviors['slug']);
        }
        if (isset($behaviors['timestamp'])) {
            unset($behaviors['timestamp']);
        }
        return $behaviors;
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['category_id', 'parent_id', 'depth', 'category_name_id', 'product_unit_id'], 'integer'],
            [['populary'], 'boolean'],
            [['path', 'image', 'meta_title', 'meta_desc', 'meta_robots', 'seo_text', 'alias'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Category::find()->with('categoryName');

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);

        $this->load($params);

        /*if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }*/

        // grid filtering conditions
        $query->andFilterWhere([
            'category_id' => $this->category_id,
            'parent_id' => $this->parent_id,
            'category_name_id' => $this->category_name_id,
            'product_unit_id' => $this->product_unit_id,
        ]);

        $query->andFilterWhere(['like', 'alias', $this->alias]);

        $query->orderBy(['path' => SORT_ASC, 'depth' => SORT_ASC]);

        return $dataProvider;
    }

    public static function findByAlias($alias) {
        /** @var CategoryQuery $query */
        $query = Category::find()
            ->with('categoryName')
            ->andFilterWhere(['alias' => $alias]);
        if (($model = $query->one()) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }

    public static function findByRemoteID($id) {
        /** @var CategoryQuery $query */
        $query = Category::find()
            ->with('categoryName')
            ->andFilterWhere(['@>', 'remote_id', ArtboxTreeHelper::setArrayField($id)]);
        if (($model = $query->one()) !== null) {
            return $model;
        }
        return null;
    }

//    public static function findByProductsKeywords($keywords = [], $category = null) {
//
//    }
}
