<?php

namespace common\modules\product\models;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use common\modules\product\models\Product;
use yii\web\NotFoundHttpException;

/**
 * ProductSearch represents the model behind the search form about `common\modules\product\models\Product`.
 */
class ProductSearch extends Product
{
    public $brand_name;
    public $category_name;

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name', 'brand_name', 'category_name'], 'safe'],
            [['tax_brand_id', 'product_id'], 'integer'],
            [['is_top', 'is_new'], 'boolean'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Product::find();

        $query->joinWith(['brand', 'brand.brandNames', 'categories', 'categories.categoryNames', 'variant']);

        $query->groupBy(['product.product_id']);
        $query->orderBy('product.product_id', 'DESC');

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);

        if ( !($this->load($params) && $this->validate()) ) {
            return $dataProvider;
        }

        $dataProvider->setSort([
            'attributes' => [
                'name',
                'brand_name' => [
                    'asc' => ['brand_name.value' => SORT_ASC],
                    'desc' => ['brand_name.value' => SORT_DESC],
                    'default' => SORT_DESC,
                    'label' => 'Brand name',
                ],
                'category_name',
                'variant_sku',
            ]
        ]);

        if (isset($this->is_top)) {
            $query->andFilterWhere([
                'is_top' => (bool)$this->is_top,
            ]);
        }
        if (isset($this->is_new)) {
            $query->andFilterWhere([
                'is_new' => (bool)$this->is_new,
            ]);
        }

        $query->andFilterWhere([
            'product.brand_id' => $this->brand_id,
            'product.product_id' => $this->product_id,
            'product_category.category_id' => $this->category_id
        ]);

        $query->andFilterWhere(['ilike', 'product.name', $this->name]);
        $query->andFilterWhere(['ilike', 'brand_name.value', $this->brand_name]);
        $query->andFilterWhere(['ilike', 'category_name.value', $this->category_name]);
        $query->andFilterWhere(['ilike', 'product_variant.sku', $this->variant_sku]);

        return $dataProvider;
    }

    public static function findByAlias($alias) {
        /** @var ProductQuery $query */
        $query = Product::find();
        $query->byAlias($alias);
        if (($model = $query->one()) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested product does not exist.');
        }
    }

    public static function findByRemoteID($id) {
        /** @var CategoryQuery $query */
        $query = Product::find()
            ->andFilterWhere(['remote_id' => $id]);
        if (($model = $query->one()) !== null) {
            return $model;
        }
        return null;
    }
}
