<?php

namespace common\modules\product\models;

use Yii;

/**
 * This is the model class for table "product_variant".
 *
 * @property integer $product_variant_id
 * @property integer $product_id
 * @property string $name
 * @property string $remote_id
 * @property string $sku
 * @property double $price
 * @property double $price_old
 * @property double $stock
 * @property integer $product_unit_id
 *
 * @property ProductUnit $productUnit
 */
class ProductVariant extends \yii\db\ActiveRecord
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'product_variant';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['product_id', 'sku', 'product_unit_id'], 'required'],
            [['product_id', 'product_unit_id'], 'integer'],
            [['price', 'price_old', 'stock'], 'number'],
            [['name', 'sku'], 'string', 'max' => 255],
            [['remote_id'], 'string', 'max' => 20],
            [['product_unit_id'], 'exist', 'skipOnError' => true, 'targetClass' => ProductUnit::className(), 'targetAttribute' => ['product_unit_id' => 'product_unit_id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'product_variant_id' => Yii::t('product', 'Product Variant ID'),
            'product_id' => Yii::t('product', 'Product ID'),
            'name' => Yii::t('product', 'Name'),
            'sku' => Yii::t('product', 'Sku'),
            'price' => Yii::t('product', 'Price'),
            'price_old' => Yii::t('product', 'Price Old'),
            'stock' => Yii::t('product', 'Stock'),
            'product_unit_id' => Yii::t('product', 'Product Unit ID'),
            'stock_caption' => Yii::t('product', 'Stock'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getProductUnit()
    {
        return $this->hasOne(ProductUnit::className(), ['product_unit_id' => 'product_unit_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getProduct()
    {
        return $this->hasOne(Product::className(), ['product_id' => 'product_id']);
    }

    public function getEnabled() {
        return $this->stock !== 0;
    }

    public function getStock_caption() {
        return is_null($this->stock) ? '∞' : intval($this->stock);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getImage()
    {
        return $this->hasOne(ProductImage::className(), ['product_variant_id' => 'product_variant_id']);
    }

    public function getImageUrl()
    {
        // return a default image placeholder if your source image is not found
        return !empty($this->image) ? $this->image->imageUrl : '/storage/no_photo.png';
    }

    /**
     * @inheritdoc
     * @return ProductVariantQuery the active query used by this AR class.
     */
    public static function find()
    {
        return new ProductVariantQuery(get_called_class());
    }
}
