<?php

namespace common\modules\product\models;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use yii\web\NotFoundHttpException;

/**
 * ProductVariantSearch represents the model behind the search form about `common\modules\product\models\ProductVariant`.
 */
class ProductVariantSearch extends ProductVariant
{
    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name', 'sku', 'price', 'price_old', 'stock'], 'safe'],
            [['product_variant_id', 'product_id'], 'integer'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = Product::find();

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'product_variant_id' => $this->product_variant_id,
            'product_id' => $this->product_id,
        ]);

        $query->andFilterWhere(['like', 'name', $this->name])
              ->andFilterWhere(['like', 'sku', $this->sku]);

        return $dataProvider;
    }

    public static function findBySku($sku) {
        /** @var ProductQuery $query */
        $query = ProductVariant::find()
                ->andFilterWhere(['sku' => $sku]);
        if (($model = $query->one()) !== null) {
            return $model;
        }
        return;
    }

    public static function findByRemoteID($id) {
        /** @var CategoryQuery $query */
        $query = ProductVariant::find()
            ->andFilterWhere(['remote_id' => $id]);
        if (($model = $query->one()) !== null) {
            return $model;
        }
        return;
    }
}
