<?php

namespace common\modules\rubrication\controllers;

use common\modules\rubrication\models\TaxGroup;
use Yii;
use common\modules\rubrication\models\TaxOption;
use common\modules\rubrication\models\TaxOptionSearch;
use yii\data\ActiveDataProvider;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;

/**
 * TaxOptionController implements the CRUD actions for TaxOption model.
 */
class TaxOptionController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all TaxOption models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new TaxOptionSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        $group = TaxGroup::findOne(Yii::$app->request->queryParams['group']);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
            'group' => $group,
        ]);
    }

    /**
     * Displays a single TaxOption model.
     * @param string $id
     * @return mixed
     */
    public function actionView($id)
    {
        $model = $this->findModel($id);
        $group = TaxGroup::findOne($model->tax_group_id);
        return $this->render('view', [
            'model' => $model,
            'group' => $group,
        ]);
    }

    /**
     * Creates a new TaxOption model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new TaxOption();
        $group = TaxGroup::findOne(Yii::$app->request->queryParams['group']);
        $valueModelName = $this->getValueModelName($group);
        $valueModel = new $valueModelName;

        if ($model->load(Yii::$app->request->post()) && $valueModel->load(Yii::$app->request->post())) {
            $model->save();

            $valueModel->tax_option_id = $model->tax_option_id;
            $valueModel->save();

            $model->default_value = $valueModel->tax_value_id;
            $model->save();

            return is_null(Yii::$app->request->post('create_and_new')) ? $this->redirect(['view', 'id' => $model->tax_option_id]) : $this->redirect(array_merge(['create'], Yii::$app->request->queryParams));
        } else {
            $model->tax_group_id = $group->tax_group_id;
            if (!empty(Yii::$app->request->queryParams['parent'])) {
                $model->parent_id = Yii::$app->request->queryParams['parent'];
            }
            return $this->render('create', [
                'model' => $model,
                'group' => $group,
                'valueModel' => $valueModel,
            ]);
        }
    }

    /**
     * Updates an existing TaxOption model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param string $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);
        $group = TaxGroup::findOne($model->tax_group_id);
        $valueModelName = $this->getValueModelName($group);
        $valueModel = $valueModelName::findOne($model->default_value);

        if ($model->load(Yii::$app->request->post()) && $valueModel->load(Yii::$app->request->post())) {
            $model->save();
            $valueModel->tax_option_id = $model->tax_option_id;
            $valueModel->save();

            $model->default_value = $valueModel->tax_value_id;
            $model->save();

            TaxOption::find()->rebuildMP($model->tax_group_id);

            return $this->redirect(['view', 'id' => $model->tax_option_id]);
        } else {
            return $this->render('update', [
                'model' => $model,
                'group' => $group,
                'valueModel' => $valueModel,
            ]);
        }
    }

    /**
     * Deletes an existing TaxOption model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param string $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        $model = $this->findModel($id);
        $group_id = $model->tax_group_id;

        $model->delete();

        return $this->redirect(['index', 'group' => $group_id]);
    }

    /**
     * Finds the TaxOption model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param string $id
     * @return TaxOption the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = TaxOption::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }

    protected function getValueModelName($group) {
        $valueClass = '\common\modules\rubrication\models\TaxValue'. ucfirst($group->module);
        return class_exists($valueClass) ? $valueClass : FALSE;
    }
}
